==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/marketplace/messages/es/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Módulo deshabilitado con éxito.',
    '
Module successfully enabled!
' => 'Módulo habilitado con éxito.',
    '
No active Professional Edition license found!
' => '¡No se encontró ninguna licencia de Professional Edition activa!',
    '
The license could not be activated:
' => 'No se pudo activar la licencia:',
    '
The license was successfully activated!

' => '¡La licencia se activó correctamente!',
    '
The license was successfully removed!

' => '¡La licencia fue eliminada con éxito!',
    '--- Disable module: {moduleId} ---

' => '--- Deshabilitar módulo: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Habilitar módulo: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Activa</strong> tu edición profesional',
    '<strong>General</strong> Settings' => 'Configuración <strong>general</strong>',
    'A new update is available (HumHub %version%)!' => 'Hay una nueva actualización disponible (HumHub %version%).',
    'Add Licence Key' => 'Añadir código de licencia',
    'Add purchased module by licence key' => 'Agregar licencia de módulo comprado',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => 'Tras instalar el módulo requerido, sólo le falta activarlo. Una vez lo haya hecho podrá comenzar a utilizar el módulo o la función. Por favor tenga en cuenta que algunos módulos requieren hacer una configuración antes de poder ser usados.',
    'All' => 'Todos',
    'All {moduleId} module content will be deleted. Continue?' => 'Se eliminará todo el contenido del módulo {moduleId}. ¿Continuar?',
    'Allow module versions in beta status' => 'Permitir utilizar versiones beta de los módulos',
    'Available Updates' => 'Actualizaciones disponibles',
    'Buy' => 'Comprar',
    'Buy (%price%)' => 'Comprar (%price%)',
    'Categories' => 'Categorías',
    'Changelog' => 'Registro de cambios',
    'Community' => 'Comunidad',
    'Configure' => 'Configurar',
    'Could not connect to HumHub API!' => '¡No puedo conectar a la API de HumHub!',
    'Could not connect to HumHub API!
' => '¡No se ha podido conectar a la API de HumHub!',
    'Could not connect to licence server!' => '¡No se pudo conectar al servidor de licencias!',
    'Could not extract module!' => '¡No se pudo extraer el módulo!',
    'Could not find requested module!' => '¡No se pudo encontrar el módulo solicitado!',
    'Could not find the requested module!' => '¡No se ha podido encontrar el módulo solicitado!',
    'Could not remove old module path!' => 'No se pudo eliminar la ruta del módulo anterior.',
    'Could not update licence. Error: ' => 'No se pudo actualizar la licencia. Error:',
    'Deprecated' => 'Obsoleto',
    'Download of module failed!' => '¡Falló la descarga del módulo!',
    'Edit licence' => 'Editar licencia',
    'Enable' => 'Activar',
    'Enable now' => 'Activar ahora',
    'Enabled' => 'Activado',
    'Featured' => 'Destacado',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => 'Encuentre todos los módulos que puede añadir a su red en la tienda de aplicaciones de HumHub. Descubra los numerosos complementos y capacidades que le permiten personalizar el software y configurar su red de acuerdo a sus propias necesidades.',
    'General Settings' => 'Ajustes generales',
    'Great!' => '¡Estupendo!',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Si este módulo es adicionalmente marcado como <strong>"Communitario"</strong> quiere decir que no es probado ni monitoreado por el equipo de Humhub.',
    'Information' => 'Información',
    'Install' => 'Instalar',
    'Installed' => 'Instalado',
    'Invalid module licence key!' => '¡La clave de licencia del módulo es inválida!',
    'Invalid module licence key!
' => '¡Clave de licencia de módulo no válida!',
    'Latest version:' => 'Última versión:',
    'Learn more' => 'Saber más',
    'Licence Key:' => 'Número de licencia:',
    'Licence key' => 'Clave de licencia',
    'Licenced for max. {number} users.' => 'Con licencia para máx. {number} usuarios.',
    'Licenced to:' => 'Con licencia para:',
    'License not found or expired. Please contact the module publisher.' => 'No se ha encontrado una licencia o está expirada. Por favor póngase en contacto con el desarrollador del módulo.',
    'Marketplace' => 'Marketplace',
    'Marketplace is disabled.' => 'La tienda de aplicaciones está deshabilitada.',
    'Max. users:' => 'Usuarios máximos:',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => 'El módulo "{moduleName}" ha sido actualizado con éxito a la versión {newVersion}.',
    'Module <strong>enabled</strong>' => 'Módulo <strong>activado</strong>',
    'Module <strong>installed</strong>' => 'Módulo <strong>instalado</strong>',
    'Module Administration' => 'Administración de módulos',
    'Module configuration' => 'Configuración de módulos',
    'Module directory %modulePath% is not writeable!' => '¡El directorio del módulo %modulePath% no es escribible!',
    'Module download failed! (%error%)' => '¡Falló la descarga del módulo! (%error%)',
    'Module is <strong>installing...</strong>' => 'Se está <strong>instalando</strong> el módulo...',
    'Module licence added!' => '¡Se ha añadido la licencia del módulo!',
    'Module licence added!
' => '¡Se ha añadido la licencia de módulo!',
    'Module licence key cannot be empty!
' => '¡La clave de licencia de módulo no puede estar vacía!',
    'Module not found!
' => 'El módulo no se ha encontrado.',
    'More info' => 'Más información',
    'New' => 'Nuevo',
    'No compatible module version found!' => '¡No se encontró una versión compatible del módulo!',
    'No license key? Find out more about the {pro} or contact us.' => '¿Sin clave de licencia? Obtenga más información sobre {pro} o contáctenos.',
    'No modules found.' => 'No se han encontrado módulos.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Ningun módulos instalados. instala unos para que se mejore la functionalidad.',
    'No purchased modules found!' => 'No se encontraron módulos comprados',
    'Official' => 'Oficial',
    'Ok' => 'Ok',
    'PROFESSIONAL EDITION' => 'EDICIÓN PROFESIONAL',
    'Partner' => 'Partner',
    'Professional Edition' => 'Edición profesional',
    'Professional Edition is activated!' => '¡La Edición Profesional está activada!',
    'Register' => 'Registrarse',
    'Remove licence key' => 'Eliminar clave de licencia',
    'Save and update' => 'Guardar y actualizar',
    'Search' => 'Buscar',
    'Search...' => 'Buscar...',
    'Settings' => 'Ajustes',
    'Stop updating' => 'Dejar de actualizar',
    'Tags' => 'Etiquetas',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'El equipo de HumHub no garantiza el funcionamiento, calidad o el contínuo desarrollo de este módulo.',
    'Third-party' => 'Terceros',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Los módulos hechos por terceros no están cubierto por los términos de la Licencia Profesional.',
    'Third-party disclaimer' => 'Aviso de responsabilidad de terceros',
    'This Module was developed by a third-party.' => 'Este módulo fue desarrollado por un tercero.',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Uninstalled' => 'No instalado',
    'Update' => 'Actualizar',
    'Update all' => 'Actualizar todos',
    'Update successful' => 'Actualización completada con éxito.',
    'Upgrade to Professional Edition' => 'Actualizar a la edición profesional',
    'Version:' => 'Versión:',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '¡Ya casi está! Como paso final, le recomendamos que eche un vistazo a la configuración del módulo, donde encontrará muchas opciones de configuración, algunas de las cuales son requeridas.',
    'Well done! To make the module available within your network, you will also need to enable it. Do you want to enable it now?' => '¡Bien hecho! Para hacer que el módulo esté disponible en su red, tendrá que activarlo también. ¿Quiere activarlo ahora?',
    'Well done! You have successfully installed and enabled the module!' => '¡Bien hecho! Ha instalado y activado el módulo correctamente.',
    'Would you like to jump straight to it?' => '¿Quiere ir directamente allí?',
    'Your HumHub installation is up to date!' => 'Tu instalación de HumHub está actualizada.',
    'All modules' => '',
    'Module not found or enabled!
' => '',
    'No, thank you!' => '',
    'Without category' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/marketplace/messages/es/base.php <==
<?php

return [
    '
Module successfully disabled!
' => 'Módulo deshabilitado con éxito.',
    '
Module successfully enabled!
' => 'Módulo habilitado con éxito.',
    '
No active Professional Edition license found!
' => '¡No se encontró ninguna licencia de Professional Edition activa!',
    '
The license could not be activated:
' => 'No se pudo activar la licencia:',
    '
The license was successfully activated!

' => '¡La licencia se activó correctamente!',
    '
The license was successfully removed!

' => '¡La licencia fue eliminada con éxito!',
    '--- Disable module: {moduleId} ---

' => '--- Deshabilitar módulo: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- Habilitar módulo: {moduleId} ---',
    '<strong>Activate</strong> your Professional Edition' => '<strong>Activa</strong> tu edición profesional',
    '<strong>General</strong> Settings' => 'Configuración <strong>general</strong>',
    'A new update is available (HumHub %version%)!' => 'Hay una nueva actualización disponible (HumHub %version%).',
    'Add License Key' => 'Añadir código de licencia',
    'Add purchased module by license key' => 'Agregar licencia de módulo comprado',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => 'Tras instalar el módulo requerido, sólo le falta activarlo. Una vez lo haya hecho podrá comenzar a utilizar el módulo o la función. Por favor tenga en cuenta que algunos módulos requieren hacer una configuración antes de poder ser usados.',
    'All' => 'Todos',
    'All modules' => 'Todos los módulos',
    'All {moduleId} module content will be deleted. Continue?' => 'Se eliminará todo el contenido del módulo {moduleId}. ¿Continuar?',
    'Allow module versions in beta status' => 'Permitir utilizar versiones beta de los módulos',
    'Available Updates' => 'Actualizaciones disponibles',
    'Buy' => 'Comprar',
    'Buy (%price%)' => 'Comprar (%price%)',
    'Categories' => 'Categorías',
    'Changelog' => 'Registro de cambios',
    'Community' => 'Comunidad',
    'Configure' => 'Configurar',
    'Could not connect to HumHub API!' => '¡No puedo conectar a la API de HumHub!',
    'Could not connect to HumHub API!
' => '¡No se ha podido conectar a la API de HumHub!',
    'Could not connect to license server!' => '¡No se pudo conectar al servidor de licencias!',
    'Could not extract module!' => '¡No se pudo extraer el módulo!',
    'Could not find requested module!' => '¡No se pudo encontrar el módulo solicitado!',
    'Could not find the requested module!' => '¡No se ha podido encontrar el módulo solicitado!',
    'Could not remove old module path!' => 'No se pudo eliminar la ruta del módulo anterior.',
    'Could not update license. Error: ' => 'No se pudo actualizar la licencia. Error:',
    'Deprecated' => 'Obsoleto',
    'Download of module failed!' => '¡Falló la descarga del módulo!',
    'Edit license' => 'Editar licencia',
    'Enable' => 'Activar',
    'Enable now' => 'Activar ahora',
    'Enabled' => 'Activado',
    'Featured' => 'Destacado',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => 'Encuentre todos los módulos que puede añadir a su red en la tienda de aplicaciones de HumHub. Descubra los numerosos complementos y capacidades que le permiten personalizar el software y configurar su red de acuerdo a sus propias necesidades.',
    'General Settings' => 'Ajustes generales',
    'Great!' => '¡Estupendo!',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Si este módulo es adicionalmente marcado como <strong>"Communitario"</strong> quiere decir que no es probado ni monitoreado por el equipo de Humhub.',
    'Information' => 'Información',
    'Install' => 'Instalar',
    'Installed' => 'Instalado',
    'Invalid module license key!' => '¡La clave de licencia del módulo es inválida!',
    'Invalid module license key!
' => '¡Clave de licencia de módulo no válida!',
    'Latest version:' => 'Última versión:',
    'Learn more' => 'Saber más',
    'License Key:' => 'Número de licencia:',
    'License key' => 'Clave de licencia',
    'License not found or expired. Please contact the module publisher.' => 'No se ha encontrado una licencia o está expirada. Por favor póngase en contacto con el desarrollador del módulo.',
    'Licensed for max. {number} users.' => 'Con licencia para máx. {number} usuarios.',
    'Licensed to:' => 'Con licencia para:',
    'Marketplace' => 'Marketplace',
    'Marketplace is disabled.' => 'La tienda de aplicaciones está deshabilitada.',
    'Max. users:' => 'Usuarios máximos:',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => 'El módulo "{moduleName}" ha sido actualizado con éxito a la versión {newVersion}.',
    'Module <strong>enabled</strong>' => 'Módulo <strong>activado</strong>',
    'Module <strong>installed</strong>' => 'Módulo <strong>instalado</strong>',
    'Module Administration' => 'Administración de módulos',
    'Module configuration' => 'Configuración de módulos',
    'Module directory %modulePath% is not writeable!' => '¡El directorio del módulo %modulePath% no es escribible!',
    'Module download failed! (%error%)' => '¡Falló la descarga del módulo! (%error%)',
    'Module is <strong>installing...</strong>' => 'Se está <strong>instalando</strong> el módulo...',
    'Module license added!' => '¡Se ha añadido la licencia del módulo!',
    'Module license added!
' => '¡Se ha añadido la licencia de módulo!',
    'Module license key cannot be empty!
' => '¡La clave de licencia de módulo no puede estar vacía!',
    'Module not found or enabled!
' => '¡No se ha encontrado el módulo o no está activado!',
    'Module not found!
' => 'El módulo no se ha encontrado.',
    'More info' => 'Más información',
    'New' => 'Nuevo',
    'No compatible module version found!' => '¡No se encontró una versión compatible del módulo!',
    'No license key? Find out more about the {pro} or contact us.' => '¿Sin clave de licencia? Obtenga más información sobre {pro} o contáctenos.',
    'No modules found.' => 'No se han encontrado módulos.',
    'No modules installed yet. Install some to enhance the functionality!' => 'Ningun módulos instalados. instala unos para que se mejore la functionalidad.',
    'No purchased modules found!' => 'No se encontraron módulos comprados',
    'No, thank you!' => '¡No, gracias!',
    'Not Installed' => 'No instalado',
    'Official' => 'Oficial',
    'Ok' => 'Ok',
    'PROFESSIONAL EDITION' => 'EDICIÓN PROFESIONAL',
    'Partner' => 'Partner',
    'Professional Edition' => 'Edición profesional',
    'Professional Edition is activated!' => '¡La Edición Profesional está activada!',
    'Register' => 'Registrarse',
    'Remove license key' => 'Eliminar clave de licencia',
    'Save and update' => 'Guardar y actualizar',
    'Search' => 'Buscar',
    'Search...' => 'Buscar...',
    'Settings' => 'Ajustes',
    'Stop updating' => 'Dejar de actualizar',
    'Tags' => 'Etiquetas',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'El equipo de HumHub no garantiza el funcionamiento, calidad o el contínuo desarrollo de este módulo.',
    'Third-party' => 'Terceros',
    'Third-party Modules are not covered by Professional Edition agreements.' => 'Los módulos hechos por terceros no están cubierto por los términos de la Licencia Profesional.',
    'Third-party disclaimer' => 'Aviso de responsabilidad de terceros',
    'This Module was developed by a third-party.' => 'Este módulo fue desarrollado por un tercero.',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Update' => 'Actualizar',
    'Update all' => 'Actualizar todos',
    'Update successful' => 'Actualización completada con éxito.',
    'Upgrade to Professional Edition' => 'Actualizar a la edición profesional',
    'Version:' => 'Versión:',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '¡Ya casi está! Como paso final, le recomendamos que eche un vistazo a la configuración del módulo, donde encontrará muchas opciones de configuración, algunas de las cuales son requeridas.',
    'Well done! To make the module available within your network, you will also need to enable it. Do you want to enable it now?' => '¡Bien hecho! Para hacer que el módulo esté disponible en su red, tendrá que activarlo también. ¿Quiere activarlo ahora?',
    'Well done! You have successfully installed and enabled the module!' => '¡Bien hecho! Ha instalado y activado el módulo correctamente.',
    'Without category' => 'Sin categoría',
    'Would you like to jump straight to it?' => '¿Quiere ir directamente allí?',
    'Your HumHub installation is up to date!' => 'Tu instalación de HumHub está actualizada.',
    'Advanced Module Search' => '',
];
